@@ -9,8 +9,8 @@ use FindBin;
 
 
 
-my $old = '1.777';
-my $new = '1.778_01';
+my $old = '1.778_01';
+my $new = '1.778_02';
  
 my $pattern_our = qr/^our \$VERSION = '\Q$old\E';/;
 my $replacement_our = "our \$VERSION = '$new';";
